#include <config.h>

/*
   **      Finnish to Phoneme rules.
   **
   **      Derived from:
   **
   **           english.c
   **
   **
   **      The Phoneme codes:
   **
   **              IY      bEEt            IH      bIt
   **              EY      gAte            EH      gEt
   **              AE      fAt             AA      fAther
   **              AO      lAWn            OW      lOne
   **              UH      fUll            UW      fOOl
   **              ER      mURdER          AX      About
   **              AH      bUt             AY      hIde
   **              AW      hOW             OY      tOY
   **
   **              p       Pack            b       Back
   **              t       Time            d       Dime
   **              k       Coat            g       Goat
   **              f       Fault           v       Vault
   **              TH      eTHer           DH      eiTHer
   **              s       Sue             z       Zoo
   **              SH      leaSH           ZH      leiSure
   **              HH      How             m       suM
   **              n       suN             NG      suNG
   **              l       Laugh           w       Wear
   **              y       Young           r       Rate
   **              CH      CHar            j       Jar
   **              WH      WHere
   **
   **
   **      Rules are made up of four parts:
   **
   **              The left context.
   **              The text to match.
   **              The right context.
   **              The phonemes to substitute for the matched text.
   **
   **      Procedure:
   **
   **              Seperate each block of letters (apostrophes included)
   **              and add a space on each side.  For each unmatched
   **              letter in the word, look through the rules where the
   **              text to match starts with the letter in the word.  If
   **              the text to match is found and the right and left
   **              context patterns also match, output the phonemes for
   **              that rule and skip to the next unmatched letter.
   **
   **
   **      Special Context Symbols:
   **
   **              #       One or more vowels
   **              :       Zero or more consonants
   **              ^       One consonant.
   **                     Yksi ei-vokaali.
   **              .       One of B, D, V, G, J, L, M, N, R, W or Z (voiced
   **                      consonants)
   **              %       One of ER, E, ES, ED, ING, ELY (a suffix)
   **                      (Found in right context only)
   **              +       One of E, I or Y (a "front" vowel)
   **
 */


#define LEFT_PART       0
#define MATCH_PART      1
#define RIGHT_PART      2
#define OUT_PART        3

typedef char *Rule[4];
 /* Rule is an array of 4 character pointers */


/*0 = Punctuation */
/*
   **      LEFT_PART       MATCH_PART      RIGHT_PART      OUT_PART
 */


static Rule all_rules[] =
{
 {"", "050", "", "'n0llVviis'n0llV  '"},
 {"", "040", "", "'n0llVnelj&'n0llV '"},
 {"", "09", "", "'n0llV'ihdeks&n  '"},
 {"", "123456", "", "iikVVkOneeviikuu"},
 {"", "12345", "", "iikVVkOneevii"},
 {"", "1234", "", "iikVVkOnee"},
 {"", "123", "", "iikVVkO"},
 {"", "12", "", "iikVV"},
 {"", "0", "", "n0llV"},
 {"", "1", "", "uks"},
 {"", "2", "", "kVks"},
 {"", "3", "", "k0lme"},
 {"", "4", "", "nelj&"},
 {"", "5", "", "fiis"},
 {"", "6", "", "kuus"},
 {"", "7", "", "seittem&"},
 {"", "8", "", "kVheksV"},
 {"", "9", "", "ihdeks&n"},
 
 {"", ", ", "", "  "},
 {"", ",", "", "  "},
 {"", " ", "", "'"},
 {"", "\r", "", "'"},
 {"", "\n", "", "'"},
 {"", "'", "", "'"},
 {"", "-", "", "  "},
 {"", ".", "", "   "},
 {"", "?", "", "'  "},
 {"", "!", "", ",  "},

 {"", "IE","", "ie"},
 {"", "AI","", "Vi"},
 {"", "AU","", "Vu"},
 {"", "EA","", "eV"},
 {"", "EU","", "eu"},
 {"", "EI","", "ei"},

 {"", "A", "", "V"},
 {"", "A", " ", "V "},
 {"", "AA", " ", "VVVV "},
 {" ", "A", "", "V"},
 {"", "A", "", "V"},

 {"", "BB", "", "mb"},
 {"", "B", "", "b"},

 {" ", "CH", "", "k"},
 {"^E", "CH", "", "k"},
 {"", "CH", "", "tS"},
 {" S", "CI", "#", "saI"},
 {"", "CI", "A", "S"},
 {"", "CI", "O", "S"},
 {"", "CI", "EN", "S"},
 {"", "C", "+", "s"},
 {"", "CK", "", "k"},
 {"", "C", "", "k"},

 {"", "DD", "", "  d"},
 {" ", " D", "", " d"},
 {"", "D", "", "d"},

 {"", "E", "", "e"},
 {"", "E", " ", "e "},
 {" ", "E", "", "e"},
 {"", "E", "", "ee"},
 
 {"", "F", "", "f"},

 {"", "G", "", "g"},

 {"", "H", "", "h"},

 {"", "I", "", "i"},
 {"", "I", " ", "i "},
 {" ", "I", "", "i"},
 {"", "I", "", "ii"},

 {"", "J", "", "j"},

 {"", "KK", "", "  k"},
 {" ", "K", "", " k"},
 {"", "K", "", "k"},

 {"", "L", "", "l"},

 {"", "M", "", "m"},

 {"", "NG", "", "NN"},
 {"", "N", "", "n"},

 {"", "O", "", "0"},
 {"", "O", " ", "0 "},
 {" ", "O", "", "0"},
 {"", "O", "", "0"},
 {"", "OO", "", "O"},

 {"", "PP", "", "  p"},
 {" ", "P", "", " p"},
 {"", "P", "", "p"},

 {"", "QQ", "", " k"},
 {" ", " Q", "", " k"},
 {"", "Q", "", "k"},

 {"", "TR", "", "tR"},
 {"", "RR", "", "RR"},
 {"", "R", "", "R"},

 {"", "SH", "", "S"},
 {"", "S", "", "s"},

 {"", "TH", "", "D"},
 {"", "TT", "", "  t"},
 {" ", "T", "", " t"},
 {"", "T", "", "t"},

 {"", "U", "", "u"},
 {"", "U", " ", "u "},
 {" ", "U", "", "u"},
 {"", "U", "", "u"},

 {"", "V", "", "v"},

 {"", "W", "", "v"},
 {"", "WH", "", "hw"},

 {"", "X", "", "ks"},

 {"", "Y", "", "y"},

 {"", "ZZ", "", "  ts"},
 {"", "Z", "", "ts"},

 {"", "", "", "&"},
 {"", "", " ", "& "},
 {" ", "", "", "&"},
 {"", "", "", "&"},
 {"", "", " ", "& "},
 {" ", "", "", "&"},
 {"", "", "", "&&&"},
 {"", "", "", "&&"},
 {"", "", "", "&&&"},
 {" ", "", "", "&"},
 {"", "", "", "&&"},

 {"", "R", "", "ER"},
 {"", "R", "", "ER"},
 {"", "", "", "@@"},
 {"", "", " ", "@@ "},
 {" ", "", "", "@@"},
 {"", "", "", "@@"},
 {"", "", " ", "@@ "},
 {" ", "", "", "@@"},
 {"", "", "", "@@@"},
 {"", "", "", "@@@"},
 {0,0,0,0}
};

Rule *Rules[] =
{
 all_rules
};
